@@ -6,9 +6,11 @@ use warnings;
 use parent 'Exporter';
 
 use Carp;
+use Hash::Merge qw(merge);
 
 use Raisin;
 use Raisin::Entity;
+# use Raisin::Util qw(merge);
 
 my @APP_CONF_METHODS = qw(
     app
@@ -92,7 +94,8 @@ sub resource {
         }
 
         my %prev_settings = %SETTINGS;
-        @SETTINGS{ keys %args } = values %args;
+        Hash::Merge::set_clone_behavior(undef);
+        %SETTINGS = %{ merge(\%SETTINGS, \%args) };
 
         # Going deeper
         $code->();
